@@ -27,4 +27,20 @@
   static_assert((condition), "Failed static assert: " #condition)
 #define VTKM_STATIC_ASSERT_MSG(condition, message) static_assert((condition), message)
 
+namespace vtkm
+{
+
+template <bool noError>
+struct ReadTheSourceCodeHereForHelpOnThisError;
+
+template <>
+struct ReadTheSourceCodeHereForHelpOnThisError<true> : std::true_type
+{
+};
+
+} // namespace vtkm
+
+#define VTKM_READ_THE_SOURCE_CODE_FOR_HELP(noError)                                                \
+  VTKM_STATIC_ASSERT(vtkm::ReadTheSourceCodeHereForHelpOnThisError<noError>::value)
+
 #endif //vtk_m_StaticAssert_h
