@@ -67,149 +67,173 @@ public class vtkHyperTreeGridSource extends vtkHyperTreeGridAlgorithm
   public void SetIndexingModeToIJK()
     { SetIndexingModeToIJK_14(); }
 
-  private native void SetBranchFactor_15(int id0);
-  public void SetBranchFactor(int id0)
-    { SetBranchFactor_15(id0); }
-
-  private native int GetBranchFactorMinValue_16();
-  public int GetBranchFactorMinValue()
-    { return GetBranchFactorMinValue_16(); }
-
-  private native int GetBranchFactorMaxValue_17();
-  public int GetBranchFactorMaxValue()
-    { return GetBranchFactorMaxValue_17(); }
-
-  private native int GetBranchFactor_18();
-  public int GetBranchFactor()
-    { return GetBranchFactor_18(); }
-
-  private native void SetDimension_19(int id0);
+  private native void SetDimension_15(int id0);
   public void SetDimension(int id0)
-    { SetDimension_19(id0); }
+    { SetDimension_15(id0); }
 
-  private native int GetDimensionMinValue_20();
+  private native int GetDimensionMinValue_16();
   public int GetDimensionMinValue()
-    { return GetDimensionMinValue_20(); }
+    { return GetDimensionMinValue_16(); }
 
-  private native int GetDimensionMaxValue_21();
+  private native int GetDimensionMaxValue_17();
   public int GetDimensionMaxValue()
-    { return GetDimensionMaxValue_21(); }
+    { return GetDimensionMaxValue_17(); }
 
-  private native int GetDimension_22();
+  private native int GetDimension_18();
   public int GetDimension()
-    { return GetDimension_22(); }
+    { return GetDimension_18(); }
 
-  private native void SetUseDescriptor_23(boolean id0);
+  private native void SetOrientation_19(int id0);
+  public void SetOrientation(int id0)
+    { SetOrientation_19(id0); }
+
+  private native int GetOrientation_20();
+  public int GetOrientation()
+    { return GetOrientation_20(); }
+
+  private native void SetBranchFactor_21(int id0);
+  public void SetBranchFactor(int id0)
+    { SetBranchFactor_21(id0); }
+
+  private native int GetBranchFactorMinValue_22();
+  public int GetBranchFactorMinValue()
+    { return GetBranchFactorMinValue_22(); }
+
+  private native int GetBranchFactorMaxValue_23();
+  public int GetBranchFactorMaxValue()
+    { return GetBranchFactorMaxValue_23(); }
+
+  private native int GetBranchFactor_24();
+  public int GetBranchFactor()
+    { return GetBranchFactor_24(); }
+
+  private native void SetUseDescriptor_25(boolean id0);
   public void SetUseDescriptor(boolean id0)
-    { SetUseDescriptor_23(id0); }
+    { SetUseDescriptor_25(id0); }
 
-  private native boolean GetUseDescriptor_24();
+  private native boolean GetUseDescriptor_26();
   public boolean GetUseDescriptor()
-    { return GetUseDescriptor_24(); }
+    { return GetUseDescriptor_26(); }
 
-  private native void UseDescriptorOn_25();
+  private native void UseDescriptorOn_27();
   public void UseDescriptorOn()
-    { UseDescriptorOn_25(); }
+    { UseDescriptorOn_27(); }
 
-  private native void UseDescriptorOff_26();
+  private native void UseDescriptorOff_28();
   public void UseDescriptorOff()
-    { UseDescriptorOff_26(); }
+    { UseDescriptorOff_28(); }
 
-  private native void SetUseMaterialMask_27(boolean id0);
+  private native void SetUseMaterialMask_29(boolean id0);
   public void SetUseMaterialMask(boolean id0)
-    { SetUseMaterialMask_27(id0); }
+    { SetUseMaterialMask_29(id0); }
 
-  private native boolean GetUseMaterialMask_28();
+  private native boolean GetUseMaterialMask_30();
   public boolean GetUseMaterialMask()
-    { return GetUseMaterialMask_28(); }
+    { return GetUseMaterialMask_30(); }
 
-  private native void UseMaterialMaskOn_29();
+  private native void UseMaterialMaskOn_31();
   public void UseMaterialMaskOn()
-    { UseMaterialMaskOn_29(); }
+    { UseMaterialMaskOn_31(); }
 
-  private native void UseMaterialMaskOff_30();
+  private native void UseMaterialMaskOff_32();
   public void UseMaterialMaskOff()
-    { UseMaterialMaskOff_30(); }
+    { UseMaterialMaskOff_32(); }
 
-  private native void SetDescriptor_31(String id0);
+  private native void SetGenerateInterfaceFields_33(boolean id0);
+  public void SetGenerateInterfaceFields(boolean id0)
+    { SetGenerateInterfaceFields_33(id0); }
+
+  private native boolean GetGenerateInterfaceFields_34();
+  public boolean GetGenerateInterfaceFields()
+    { return GetGenerateInterfaceFields_34(); }
+
+  private native void GenerateInterfaceFieldsOn_35();
+  public void GenerateInterfaceFieldsOn()
+    { GenerateInterfaceFieldsOn_35(); }
+
+  private native void GenerateInterfaceFieldsOff_36();
+  public void GenerateInterfaceFieldsOff()
+    { GenerateInterfaceFieldsOff_36(); }
+
+  private native void SetDescriptor_37(String id0);
   public void SetDescriptor(String id0)
-    { SetDescriptor_31(id0); }
+    { SetDescriptor_37(id0); }
 
-  private native String GetDescriptor_32();
+  private native String GetDescriptor_38();
   public String GetDescriptor()
-    { return GetDescriptor_32(); }
+    { return GetDescriptor_38(); }
 
-  private native void SetMaterialMask_33(String id0);
+  private native void SetMaterialMask_39(String id0);
   public void SetMaterialMask(String id0)
-    { SetMaterialMask_33(id0); }
+    { SetMaterialMask_39(id0); }
 
-  private native String GetMaterialMask_34();
+  private native String GetMaterialMask_40();
   public String GetMaterialMask()
-    { return GetMaterialMask_34(); }
+    { return GetMaterialMask_40(); }
 
-  private native void SetDescriptorBits_35(vtkBitArray id0);
+  private native void SetDescriptorBits_41(vtkBitArray id0);
   public void SetDescriptorBits(vtkBitArray id0)
-    { SetDescriptorBits_35(id0); }
+    { SetDescriptorBits_41(id0); }
 
-  private native long GetDescriptorBits_36();
+  private native long GetDescriptorBits_42();
   public vtkBitArray GetDescriptorBits() {
-    long temp = GetDescriptorBits_36();
+    long temp = GetDescriptorBits_42();
 
     if (temp == 0) return null;
     return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetLevelZeroMaterialIndex_37(vtkIdTypeArray id0);
+  private native void SetLevelZeroMaterialIndex_43(vtkIdTypeArray id0);
   public void SetLevelZeroMaterialIndex(vtkIdTypeArray id0)
-    { SetLevelZeroMaterialIndex_37(id0); }
+    { SetLevelZeroMaterialIndex_43(id0); }
 
-  private native void SetMaterialMaskBits_38(vtkBitArray id0);
+  private native void SetMaterialMaskBits_44(vtkBitArray id0);
   public void SetMaterialMaskBits(vtkBitArray id0)
-    { SetMaterialMaskBits_38(id0); }
+    { SetMaterialMaskBits_44(id0); }
 
-  private native long GetMaterialMaskBits_39();
+  private native long GetMaterialMaskBits_45();
   public vtkBitArray GetMaterialMaskBits() {
-    long temp = GetMaterialMaskBits_39();
+    long temp = GetMaterialMaskBits_45();
 
     if (temp == 0) return null;
     return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetQuadric_40(vtkQuadric id0);
+  private native void SetQuadric_46(vtkQuadric id0);
   public void SetQuadric(vtkQuadric id0)
-    { SetQuadric_40(id0); }
+    { SetQuadric_46(id0); }
 
-  private native long GetQuadric_41();
+  private native long GetQuadric_47();
   public vtkQuadric GetQuadric() {
-    long temp = GetQuadric_41();
+    long temp = GetQuadric_47();
 
     if (temp == 0) return null;
     return (vtkQuadric)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native void SetQuadricCoefficients_42(double id0[]);
+  private native void SetQuadricCoefficients_48(double id0[]);
   public void SetQuadricCoefficients(double id0[])
-    { SetQuadricCoefficients_42(id0); }
+    { SetQuadricCoefficients_48(id0); }
 
-  private native void GetQuadricCoefficients_43(double id0[]);
+  private native void GetQuadricCoefficients_49(double id0[]);
   public void GetQuadricCoefficients(double id0[])
-    { GetQuadricCoefficients_43(id0); }
+    { GetQuadricCoefficients_49(id0); }
 
-  private native int GetMTime_44();
+  private native int GetMTime_50();
   public int GetMTime()
-    { return GetMTime_44(); }
+    { return GetMTime_50(); }
 
-  private native long ConvertDescriptorStringToBitArray_45(String id0);
+  private native long ConvertDescriptorStringToBitArray_51(String id0);
   public vtkBitArray ConvertDescriptorStringToBitArray(String id0) {
-    long temp = ConvertDescriptorStringToBitArray_45(id0);
+    long temp = ConvertDescriptorStringToBitArray_51(id0);
 
     if (temp == 0) return null;
     return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
 }
 
-  private native long ConvertMaterialMaskStringToBitArray_46(String id0);
+  private native long ConvertMaterialMaskStringToBitArray_52(String id0);
   public vtkBitArray ConvertMaterialMaskStringToBitArray(String id0) {
-    long temp = ConvertMaterialMaskStringToBitArray_46(id0);
+    long temp = ConvertMaterialMaskStringToBitArray_52(id0);
 
     if (temp == 0) return null;
     return (vtkBitArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
