@@ -35,6 +35,22 @@ public class vtkSimpleMotionBlurPass extends vtkDepthImageProcessingPass
   public void SetColorFormat(int id0)
     { SetColorFormat_6(id0); }
 
+  private native long GetDepthTexture_7();
+  public vtkTextureObject GetDepthTexture() {
+    long temp = GetDepthTexture_7();
+
+    if (temp == 0) return null;
+    return (vtkTextureObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
+}
+
+  private native long GetColorTexture_8();
+  public vtkTextureObject GetColorTexture() {
+    long temp = GetColorTexture_8();
+
+    if (temp == 0) return null;
+    return (vtkTextureObject)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
+}
+
   public vtkSimpleMotionBlurPass() { super(); }
 
   public vtkSimpleMotionBlurPass(long id) { super(id); }
